<br>
<div align="left"><img src="{{ userObj.avater }}" class="mdui-img-fluid mdui-img-circle" width="200" height="200"><br>
    <div style="white-space:nowrap" class="mdui-typo"><strong class="mdui-typo-headline">{{userObj.nickname}}</strong>
        <div class="mdui-chip"><span class="mdui-chip-title">{{userObj.user_group}}</span></div>
        <kbd>加入于{{getTimer(userObj.registertime,True)}}</kbd>
    </div><br>
    <div class="mdui-divider"></div>
    <div class="mdui-tab" mdui-tab><a href="#post" class="mdui-ripple">帖子与回复</a><a href="#des"
            class="mdui-ripple">简介</a></div>
    <div id="post" class="mdui-p-a-2">{%if lastedPost==[]%}<strong
            class="mdui-typo-title">用户还没发布任何帖子或者回复呢</strong>{%endif%}{%for p in lastedPost%}<li class="mdui-list-item">
            <div class="mdui-list-item-content">
                <div class="mdui-list-item-avatar"><a href="/u/{{ userObj.id }}"><img width="200" height="200"
                            class="mdui-img-circle" src="{{ userObj.avater }}" /></a></div>
                <div class="mdui-list-item-title mdui-typo">
                    <kbd>{{userObj.nickname}}</kbd><kbd>{{getTimer(p.pushingtime)}}</kbd></div>
                <div class="mdui-typo">{{p.body}}</div>
                <div class="mdui-divider"></div>
            </div><br />
        </li>{%endfor%}</ul>
    </div>
    <div id="des" class="mdui-p-a-2">
        <div class="mdui-typo">{{userObj.user_des}}</div>
    </div>
</div>