<div class="mdui-typo-headline">验证邮箱</div><br><br>
<form action="/settings/check" method="POST">
  <div class="mdui-textfield"><i class="mdui-icon material-icons">code</i><label
      class="mdui-textfield-label">验证码</label><input class="mdui-textfield-input" type="number" name="code" />
    <div class="mdui-textfield-helper">输入发送到新邮箱的验证代码</div>
  </div><br><button type="submit" class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">验证并修改邮箱</button>
</form>