<div class="mdui-row mdui-row-gapless">
    <div class="mdui-col-xs-3">{{adminList}}</div>
    <div class="mdui-col-xs-1"></div>
    <div class="mdui-col-xs-7">
        <div class="mdui-typo-headline">插件</div><br><br>
    </div>
</div>