/**
 * Eric Meyer's Reset CSS v2.0 (http://meyerweb.com/eric/tools/css/reset/)
 * http://cssreset.com
 */
html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed,
figure, figcaption, footer, header, hgroup,
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}

/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure,
footer, header, hgroup, menu, nav, section {
  display: block;
}

body {
  line-height: 1;
}

ol, ul {
  list-style: none;
}

blockquote, q {
  quotes: none;
}

blockquote:before, blockquote:after,
q:before, q:after {
  content: '';
  content: none;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

.highlight .hll {
  background-color: #ffffcc;
}

.highlight .c {
  color: #999988;
  font-style: italic;
}

/* Comment */
.highlight .err {
  color: #a61717;
  background-color: #e3d2d2;
}

/* Error */
.highlight .k {
  font-weight: bold;
}

/* Keyword */
.highlight .o {
  font-weight: bold;
}

/* Operator */
.highlight .cm {
  color: #999988;
  font-style: italic;
}

/* Comment.Multiline */
.highlight .cp {
  color: #999999;
  font-weight: bold;
}

/* Comment.Preproc */
.highlight .c1 {
  color: #999988;
  font-style: italic;
}

/* Comment.Single */
.highlight .cs {
  color: #999999;
  font-weight: bold;
  font-style: italic;
}

/* Comment.Special */
.highlight .gd {
  color: #000000;
  background-color: #ffdddd;
}

/* Generic.Deleted */
.highlight .ge {
  font-style: italic;
}

/* Generic.Emph */
.highlight .gr {
  color: #aa0000;
}

/* Generic.Error */
.highlight .gh {
  color: #999999;
}

/* Generic.Heading */
.highlight .gi {
  color: #000000;
  background-color: #ddffdd;
}

/* Generic.Inserted */
.highlight .go {
  color: #888888;
}

/* Generic.Output */
.highlight .gp {
  color: #555555;
}

/* Generic.Prompt */
.highlight .gs {
  font-weight: bold;
}

/* Generic.Strong */
.highlight .gu {
  color: #aaaaaa;
}

/* Generic.Subheading */
.highlight .gt {
  color: #aa0000;
}

/* Generic.Traceback */
.highlight .kc {
  font-weight: bold;
}

/* Keyword.Constant */
.highlight .kd {
  font-weight: bold;
}

/* Keyword.Declaration */
.highlight .kn {
  font-weight: bold;
}

/* Keyword.Namespace */
.highlight .kp {
  font-weight: bold;
}

/* Keyword.Pseudo */
.highlight .kr {
  font-weight: bold;
}

/* Keyword.Reserved */
.highlight .kt {
  color: #445588;
  font-weight: bold;
}

/* Keyword.Type */
.highlight .m {
  color: #009999;
}

/* Literal.Number */
.highlight .s {
  color: #bb8844;
}

/* Literal.String */
.highlight .na {
  color: #008080;
}

/* Name.Attribute */
.highlight .nb {
  color: #999999;
}

/* Name.Builtin */
.highlight .nc {
  color: #445588;
  font-weight: bold;
}

/* Name.Class */
.highlight .no {
  color: #008080;
}

/* Name.Constant */
.highlight .ni {
  color: #800080;
}

/* Name.Entity */
.highlight .ne {
  color: #990000;
  font-weight: bold;
}

/* Name.Exception */
.highlight .nf {
  color: #990000;
  font-weight: bold;
}

/* Name.Function */
.highlight .nn {
  color: #555555;
}

/* Name.Namespace */
.highlight .nt {
  color: #000080;
}

/* Name.Tag */
.highlight .nv {
  color: #008080;
}

/* Name.Variable */
.highlight .ow {
  font-weight: bold;
}

/* Operator.Word */
.highlight .w {
  color: #bbbbbb;
}

/* Text.Whitespace */
.highlight .mf {
  color: #009999;
}

/* Literal.Number.Float */
.highlight .mh {
  color: #009999;
}

/* Literal.Number.Hex */
.highlight .mi {
  color: #009999;
}

/* Literal.Number.Integer */
.highlight .mo {
  color: #009999;
}

/* Literal.Number.Oct */
.highlight .sb {
  color: #bb8844;
}

/* Literal.String.Backtick */
.highlight .sc {
  color: #bb8844;
}

/* Literal.String.Char */
.highlight .sd {
  color: #bb8844;
}

/* Literal.String.Doc */
.highlight .s2 {
  color: #bb8844;
}

/* Literal.String.Double */
.highlight .se {
  color: #bb8844;
}

/* Literal.String.Escape */
.highlight .sh {
  color: #bb8844;
}

/* Literal.String.Heredoc */
.highlight .si {
  color: #bb8844;
}

/* Literal.String.Interpol */
.highlight .sx {
  color: #bb8844;
}

/* Literal.String.Other */
.highlight .sr {
  color: #808000;
}

/* Literal.String.Regex */
.highlight .s1 {
  color: #bb8844;
}

/* Literal.String.Single */
.highlight .ss {
  color: #bb8844;
}

/* Literal.String.Symbol */
.highlight .bp {
  color: #999999;
}

/* Name.Builtin.Pseudo */
.highlight .vc {
  color: #008080;
}

/* Name.Variable.Class */
.highlight .vg {
  color: #008080;
}

/* Name.Variable.Global */
.highlight .vi {
  color: #008080;
}

/* Name.Variable.Instance */
.highlight .il {
  color: #009999;
}

/* Literal.Number.Integer.Long */
/* General Style */
body {
  font-size: 16px;
  font-family: Helvetica, Arial, sans-serif;
  color: #52514c;
  background: #ffffff;
}

a {
  text-decoration: none;
  color: #4298BA;
}
a:visited {
  color: #4298BA;
}
a:hover {
  color: #0F769F;
}
a:active {
  color: #9E792E;
}
a:hover, a:active {
  outline: 0;
}

/* Layout */
.wrapper {
  width: 960px;
  margin: 0 auto;
}
.wrapper header {
  padding: 50px 0 15px;
}
.wrapper header h1 {
  width: 300px;
  margin: 0 auto;
  padding: 130px 0 0 0;
  background-position: 4px 0;
  background-image: url("../images/logo.png");
  background-repeat: no-repeat;
  background-size: 264px 107px;
}
@media all and (-webkit-min-device-pixel-ratio: 1.5), all and (-o-min-device-pixel-ratio: 3 / 2), all and (min--moz-device-pixel-ratio: 1.5), all and (min-device-pixel-ratio: 1.5) {
  .wrapper header h1 {
    background-image: url("../images/logo@2x.png");
    background-size: 264px 107px;
  }
}
.wrapper header h1 a {
  display: block;
  width: 180px;
  height: 50px;
  margin: 0 auto;
  font-size: 50px;
  font-family: 'Myriad', 'Helvetica Neue', Helvetica;
  color: #3b5f6d;
  text-align: center;
  text-indent: -9999px;
  overflow: hidden;
  background-position: center 0;
  background-image: url("../images/title.png");
  background-repeat: no-repeat;
  background-size: 171px 39px;
}
@media all and (-webkit-min-device-pixel-ratio: 1.5), all and (-o-min-device-pixel-ratio: 3 / 2), all and (min--moz-device-pixel-ratio: 1.5), all and (min-device-pixel-ratio: 1.5) {
  .wrapper header h1 a {
    background-image: url("../images/title@2x.png");
    background-size: 171px 39px;
  }
}
.wrapper header .desc {
  font-size: 19px;
  color: #9ba5a9;
  text-align: center;
}
.wrapper nav {
  text-align: center;
  padding: 26px 0;
}
.wrapper nav a {
  padding: 0 25px;
  font-size: 16px;
  color: #4f838f;
  line-height: 20px;
}
.wrapper nav a:hover {
  color: #666666;
}
.wrapper nav a.active {
  color: #000000;
}
.wrapper section {
  border-top: 2px solid #dee7ec;
}
.wrapper footer {
  font-size: 14px;
  margin: 40px 0;
  color: #999999;
  text-align: center;
}
.wrapper footer a {
  color: #999999;
}
.wrapper footer a:hover {
  text-decoration: underline;
}
.wrapper #link-fork {
  display: block;
  width: 133px;
  height: 133px;
  position: absolute;
  top: 0;
  right: 0;
}

/* Demo Page */
section#page-demo {
  border-top: none;
}
section#page-demo .simditor {
  box-shadow: 0 8px 40px rgba(0, 0, 0, 0.15);
}
section#page-demo #preview {
  min-height: 100px;
  padding: 15px;
  margin: 60px 0 0 0;
  border: 1px solid #dfdfdf;
}

/* Sidebar Page */
section.page-sidebar {
  position: relative;
  margin: 0 0 30px 0;
}
section.page-sidebar aside {
  width: 180px;
  padding: 50px 0 0 0;
  position: absolute;
  top: 0;
  left: 0;
}
section.page-sidebar aside ul {
  padding: 0 10px 0 60px;
}
section.page-sidebar aside ul li {
  margin: 0 0 30px 0;
  position: relative;
}
section.page-sidebar aside ul li .icon {
  display: none;
  width: 10px;
  line-height: 20px;
  font-size: 14px;
  color: #000000;
  position: absolute;
  top: 0;
  left: -18px;
}
section.page-sidebar aside ul li a {
  line-height: 20px;
  font-size: 18px;
  color: #a3afb2;
}
section.page-sidebar aside ul li a:hover {
  color: #666666;
}
section.page-sidebar aside ul li.active .icon {
  display: block;
}
section.page-sidebar aside ul li.active a {
  color: #000000;
}
section.page-sidebar article {
  padding: 40px 20px 10px 60px;
  margin: 0 0 0 180px;
  min-height: 500px;
}

/* Download Page */
section#page-download {
  min-height: 400px;
}
section#page-download .version {
  border-bottom: 1px solid #dfdfdf;
}
section#page-download .version .title {
  padding: 15px 15px;
  cursor: pointer;
}
section#page-download .version .title .icon {
  display: inline-block;
  width: 12px;
  line-height: 30px;
  font-size: 20px;
}
section#page-download .version .title .name {
  font-size: 20px;
  line-height: 30px;
  font-weight: bold;
  margin: 0 20px;
}
section#page-download .version .title .date {
  font-size: 16px;
  line-height: 30px;
  color: #aaaaaa;
}
section#page-download .version .title .btn-download {
  display: inline-block;
  float: right;
  line-height: 30px;
  padding: 0 15px;
  font-size: 14px;
  color: #ffffff;
  background: #aaaaaa;
  border-radius: 3px;
}
section#page-download .version .title .btn-download:hover {
  background: #bbbbbb;
}
section#page-download .version .release-notes {
  display: none;
  margin: 10px 0 25px 0;
  padding: 0 50px;
  list-style: disc outside none;
}
section#page-download .version .release-notes li {
  margin: 0 0 10px 0;
}
section#page-download .version.expand .release-notes {
  display: block;
}

/* Document Page */
section.page-doc dt {
  border-top: 1px solid #ddd;
  margin-top: 30px;
  margin-bottom: 10px;
  padding-top: 20px;
}
section.page-doc dt:first-child {
  border-top: none;
  margin-top: 0;
  padding-top: 0;
}
section.page-doc dt > a, section.page-doc dt > span {
  margin-left: 10px;
}
section.page-doc dt > a:first-child, section.page-doc dt > span:first-child {
  margin-left: 0;
}
section.page-doc dt .name {
  font-size: 1.2em;
  font-weight: bold;
}
section.page-doc dt .param-type,
section.page-doc dt .type {
  background-color: #efefef;
  border-radius: 3px;
  padding: 2px 6px;
  font-size: 0.8em;
  vertical-align: text-top;
}
section.page-doc dt .default {
  color: #aaa;
  font-size: 0.8em;
}
section.page-doc dt .params:before {
  content: "(";
}
section.page-doc dt .params:after {
  content: ")";
}
section.page-doc dt .params .param:after {
  content: ",";
  margin: 0 6px 0 3px;
}
section.page-doc dt .params .param:last-child:after {
  content: "";
  margin: 0;
}
section.page-doc dt .return {
  font-size: 0.8em;
  color: green;
}
section.page-doc dd {
  display: none;
}
section.page-doc dd.expand {
  display: block;
}

/* Extension Page */
section#page-extension article {
  padding: 40px 130px 10px;
}
section#page-extension article #btn-submit-extension {
  margin: 20px 0 0 0;
  display: inline-block;
  padding: 6px 12px;
  color: #333333;
  border: 1px solid #cccccc;
  border-radius: 4px;
}
section#page-extension article #btn-submit-extension:hover {
  border-color: #aaaaaa;
  background: #f3f3f3;
}
